<?php

global $plugin_dir, $plugin_url;
$plugin_dir = plugin_dir_path(__FILE__);
define('plugin_url', WP_CONTENT_URL . '/plugins/' . plugin_basename(dirname(__FILE__)) . '/');
$classes = array(
	$plugin_dir . 'classes'
);
foreach ($classes as $class) {
	if (($handle = opendir($class)) !== false) {
		while (false !== ($file = readdir($handle))) {
			if ($file != "." && $file != "..") {
				if (is_file($class . "/" . $file)) {
					include_once $class . "/" . $file;
				}
			}
		}
	}
}
new qtm_google_maps();

class qtm_google_maps {

	public $plugin_name;
	public $conform_key;
	public $form_code;

	public function __construct() {
		global $pluginname, $confirmationkey, $mapFormcode;
		$this->conform_key = $confirmationkey;
		$this->plugin_name = $pluginname;
		$this->form_code = $mapFormcode;
		add_action('init', array($this, 'init'));
		add_action('admin_menu', array(&$this, 'admin_menu'));
		register_deactivation_hook(__FILE__, array(&$this, 'google_map_deactivate'));
	}

	public function init() {
		if (isset($_GET['activate']) && $_GET['activate'] == 'true') {
			self::generate_tables();
		}
		$this->handleForms();
		wp_deregister_script('qtm-google-map');
		wp_deregister_script('google-map-api');

		// Register them with fresh calls
		wp_register_script('google-map-api', 'http://maps.google.com/maps/api/js?sensor=false');
		wp_register_script('qtm-google-map', plugin_url . 'js/google_map.js');

		// Include them
		wp_enqueue_script('qtm-google-map');
		wp_enqueue_script('google-map-api');
		wp_enqueue_script('google-style', plugin_url . 'css/style.css');
	}

	public function admin_menu() {
		if (get_option("google-plugin-status") == $this->conform_key) {
			add_menu_page(__($this->plugin_name), __($this->plugin_name), 6, 'google-map', array(&$this, 'google_map_list'));
			add_submenu_page('google-map', 'Map List', 'Map List', 6, 'google-map', array(&$this, 'google_map_list'));
			add_submenu_page('google-map', 'Add Map', 'Add Map', 10, 'google-map-add', array(&$this, 'google_map_add'));
		} else {
			add_menu_page(__($this->plugin_name), __($this->plugin_name), 6, 'google-map', array(&$this, 'google_map_confirm'));
			add_submenu_page('google-map', 'Map List', 'Map List', 6, 'google-map', array(&$this, 'google_map_confirm'));
			add_submenu_page('google-map', 'Add Map', 'Add Map', 10, 'google-map-add', array(&$this, 'google_map_confirm'));
		}
	}

	public static function generate_tables() {
		global $wpdb, $table_prefix;
		$Tablename = $table_prefix . "google_map";
		if ($wpdb->get_var("show tables like '$Tablename'") != $Tablename) {
			$sql = "CREATE TABLE IF NOT EXISTS `$Tablename` (
		  `id` int(11)  NOT NULL AUTO_INCREMENT,
		  `address` text NOT NULL,
		  `city` varchar(100)  NOT NULL,
		  `state` varchar(100)  NOT NULL,
		  `postcode` varchar(16) NOT NULL,
		  `title` varchar(50) NOT NULL,
		  `message` text  NOT NULL,
		  `zoom_level` int(5)  NOT NULL,
		  `height` int(10)  NOT NULL,
		  `width` int(10)  NOT NULL,
		  `street_view` smallint(1) NOT NULL,
		   PRIMARY KEY (`id`));";
			$wpdb->query($sql);
		}
		$google_column_name = "country";
		$columns_query = "SHOW COLUMNS FROM " . $Tablename . " LIKE '" . $google_column_name . "'";
		$columns_name = $wpdb->get_row($columns_query);
		if (!($columns_name->Field)) {
			$sql = "ALTER TABLE " . $Tablename . " ADD " . $google_column_name . " VARCHAR(300) NULL";
			$wpdb->query($sql);
		}
		$google_column_name = "align";
		$columns_query = "SHOW COLUMNS FROM " . $Tablename . " LIKE '" . $google_column_name . "'";
		$columns_name = $wpdb->get_row($columns_query);
		if (!($columns_name->Field)) {
			$sql = "ALTER TABLE " . $Tablename . " ADD " . $google_column_name . " VARCHAR(50) NULL";
			$wpdb->query($sql);
		}
		$google_column_name = "direction";
		$columns_query = "SHOW COLUMNS FROM " . $Tablename . " LIKE '" . $google_column_name . "'";
		$columns_name = $wpdb->get_row($columns_query);
		if (!($columns_name->Field)) {
			$sql = "ALTER TABLE `$Tablename` ADD `$google_column_name` INT( 2 ) NOT NULL DEFAULT '0'";
			$wpdb->query($sql);
		}
	}

	protected function handleForms() {
		if (isset($_REQUEST['submit_form']) && $_REQUEST['submit_form'] != "") {
			$method = "handle_" . $_REQUEST['submit_form'];
			$this->$method();
		}
	}

	protected function handle_delete_map() {
		$id = (isset($_REQUEST['id']) && is_numeric($_REQUEST['id']) && $_REQUEST['id'] > 0) ? $_REQUEST['id'] : '';
		if ($id != "") {
			$google_map = new qtm_google_map();
			$google_map->delete_google_map($id);
			header("Location: admin.php?page=google-map&saved=delete");
			exit();
		}
		header("Location: admin.php?page=google-map");
		exit();
	}

	protected function handle_map() {
		$google_map = new qtm_google_map();
		$id = 0;
		if (isset($_POST['submit'])) {
			$arrRemove = array('id', 'submit', 'submit_form', 'street_view');
			$saveData = array();
			$id = $_POST['id'];
			$saveData['street_view'] = (isset($_POST['street_view'])) ? '1' : '0';
			$saveData['direction'] = (isset($_POST['direction'])) ? '1' : '0';
			foreach ($_POST as $key => $value) {
				if (in_array($key, $arrRemove)

					)continue;
				$saveData[$key] = $value;
			}
			$meassge = $google_map->save_google_map($id, $saveData);
			header("Location: admin.php?page=google-map&saved=" . $meassge);
			exit();
		}
		header("Location: admin.php?page=google-map-add");
		exit();
	}

	public function google_map_list() {
		global $plugin_dir, $message;

		$google_map = new qtm_google_map();

		if (isset($_REQUEST['saved'])) {
			$message = '<div class="updated fade" id="message"><p>Map  ' . ucfirst($_REQUEST['saved']) . ' Successfully.</p></div>';
		}
		include_once $plugin_dir . 'pages/map.list.php';
	}

	public function google_map_add() {
		global $plugin_dir, $message;
		$arr_map = array();
		if (isset($_GET['id'])) {
			$google_map = new qtm_google_map();
			$arr_map = $google_map->get_map_by_id($_GET['id']);
		}
		include_once $plugin_dir . 'pages/map.add.php';
	}

	public function google_map_display($arrId) {
		if ($arrId['id']) {
			$google_map = new qtm_google_map();
			$arr_map = $google_map->get_map_by_id($arrId['id']);
			$zoomlevel = 15;
			if ($arr_map) {
				$address = $arr_map->address . ', ' . $arr_map->city . ', ' . $arr_map->state . ', ' . $arr_map->country . ' ' . $arr_map->postcode;
				$arrDir = $google_map->get_map_longitude($address);
				if (!$arrDir['latitude']) {
					$address = $arr_map->address . ', ' . $arr_map->city . ', ' . $arr_map->state . ', ' . $arr_map->country;
					$arrDir = $google_map->get_map_longitude($address);
				}
				if (!empty($arr_map->zoom_level) && $arr_map->zoom_level != 0)
					$zoomlevel = $arr_map->zoom_level;
				$message = str_replace(array("\n", "\r", "'", '<br/>'), "", $arr_map->message);
				$onclick = "onclick=calcRoute('" . $arrDir['latitude'] . "','" . $arrDir['longitude'] . "',document.getElementById('direction').value)";
				$content = "<div style='width:100%'>";
				$content .= '<div id="map_canvas" class="' . $arr_map->align . '" style="width: ' . $arr_map->width . 'px; height: ' . $arr_map->height . 'px;clear:both;"></div>';
				if ($arr_map->direction == 1) {
					$content.='<div id="directionsPanel" class="' . $arr_map->align . '" style="width: ' . $arr_map->width . 'px;clear:both;"></div>';
					$content.='<div class="' . $arr_map->align . '" style="width: ' . $arr_map->width . 'px;clear:both;" >';
					$content .='<input type=text id=direction name=direction />';
					$content .="<input type=button value=Search name=search $onclick />";
					$content.='</div>';
				}
				if ($arr_map->street_view == 1) {
					$content.='<div id="pano" class="' . $arr_map->align . '" style="width: ' . $arr_map->width . 'px; height: ' . $arr_map->height . 'px;margin-top:10px;clear:both;"></div>';
				}
				$content.='</div>';
				$content .= "<script type='text/javascript'>";
				$content.='simple_google_map("' . $arrDir['latitude'] . '","' . $arrDir['longitude'] . '","' . $zoomlevel . '","' . $message . '","' . $arr_map->street_view . '");';
				$content.="</script>";
				return $content;
			}
		}
	}

	function google_map_tinybutton($buttons) {
		array_push($buttons, "separator", "googleMapplugin");
		return $buttons;
	}

	function google_map_tinyregister($plugin_array) {
		$url = plugin_url . "js/map-tiny.js";
		$plugin_array["googleMapplugin"] = $url;
		return $plugin_array;
	}

	function google_map_confirm() {
		if (isset($_POST["vi_submit"]) && $_POST["vi_submit"] == "Install") {
			if ($this->conform_key != md5($_POST["vi_install_Key"])) {
				$message = "Confirmation Key Invalid";
			} else {
				if (!get_option("google-plugin-status"))
					add_option("google-plugin-status", md5($_POST["vi_install_Key"]));
				else
					update_option("google-plugin-status", md5($_POST["vi_install_Key"]));
				echo "<SCRIPT language=JavaScript>window.location='admin.php?page=google-map-add'</SCRIPT>";
			}
		}
		include_once $plugin_dir . 'pages/map.confirm.php';
	}

	function google_direction() {
?>
		<script>
			var directionDisplay;
			var directionsService ;
			directionsService = new google.maps.DirectionsService();
			var map;
		</script>
<?php

	}

}

add_action('wp_footer', array('qtm_google_maps', 'google_direction'));
add_filter('mce_external_plugins', array('qtm_google_maps', 'google_map_tinyregister'));
add_filter('mce_buttons', array('qtm_google_maps', 'google_map_tinybutton'), 0);
add_shortcode('wpGooglemap', array('qtm_google_maps', 'google_map_display'));
?>